from IPython.display import display, Javascript, HTML
import json
import os 
import pandas as pd
import time
dir_path = os.path.dirname(os.path.realpath(__file__))
print(dir_path)



def schema_from_conn(conn):
    schema = {}
    tableQuery= """SELECT name FROM sqlite_master WHERE type ='table' AND name NOT LIKE 'sqlite_%';"""
    tables = pd.read_sql_query(tableQuery, conn)['name']

    for i in tables:
        headerQuery = "select * from "+i+" where 1=2"
        headers = list(pd.read_sql_query(headerQuery, conn))
        schema[i] = headers

    return schema

def visualize(s, schema):
    display(Javascript("""
        require.config({
            paths: {
                d3: 'https://d3js.org/d3.v5.min'
            }
        });
    """))

    display(HTML(filename= dir_path + '/styles.css.html'))
    display(Javascript(filename= dir_path + '/visualize.js'))

    #First, escape all quotation marks.
    q = s.replace('"', '\"')
    query = q.replace('\n', '')
    
    shortSchema = json.dumps(schema)

    return Javascript("""
        (function(element) {
            var query = '"""+query+ """';
            var schema = """+shortSchema+""";

            require(['viz'], function(viz) {
                viz(element.get(0), query, schema)
            });
        })(element);
    """)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sqlvis", 
    version="0.0.1",
    author="Daphne Miedema",
    author_email="daphnemiedema@hotmail.com",
    description="A package to represent SQL queries as graphs.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Giraphne/SQLvis",
    packages=setuptools.find_packages(),
    package_data={'': ['SQLvis/*']},
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)